
# Slot: primary_email


The main email address of a person

URI: [nwb_schema_language:Namespaces_primary_email](https://w3id.org/p2p_ld/nwb-schema-language/Namespaces_primary_email)


## Domain and Range

[Namespaces](Namespaces.md) &#8594;  <sub>0..1</sub> [String](types/String.md)

## Parents

 *  is_a: [primary_email](primary_email.md)

## Children


## Used by

 * [Namespaces](Namespaces.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | schema:email |

